@@ -252,7 +252,7 @@ class Worker:
         return blob_name, params, offset, retry_count, batch_count, next_chunk
 
     def _process_blob_by_segments(self, blob_name, func, params):
-        batch = []
+        batch, result, failures = [], [], []
         in_blob = self._get_input_blob(blob_name)
         blobs_iterator = self._read_blob_by_segments(in_blob)
         for source_segment in blobs_iterator:
